package com.ruoyi.syzy.mapper;

import java.util.List;
import com.ruoyi.syzy.domain.BWwwNewsRef;

/**
 * 通关指南Mapper接口
 * 
 * @author voluntary
 * @date 2023-10-19
 */
public interface BWwwNewsRefMapper 
{
    /**
     * 查询通关指南
     * 
     * @param id 通关指南主键
     * @return 通关指南
     */
    public BWwwNewsRef selectBWwwNewsRefById(Long id);

    /**
     * 查询通关指南列表
     * 
     * @param bWwwNewsRef 通关指南
     * @return 通关指南集合
     */
    public List<BWwwNewsRef> selectBWwwNewsRefList(BWwwNewsRef bWwwNewsRef);

    /**
     * 新增通关指南
     * 
     * @param bWwwNewsRef 通关指南
     * @return 结果
     */
    public int insertBWwwNewsRef(BWwwNewsRef bWwwNewsRef);

    /**
     * 修改通关指南
     * 
     * @param bWwwNewsRef 通关指南
     * @return 结果
     */
    public int updateBWwwNewsRef(BWwwNewsRef bWwwNewsRef);

    /**
     * 删除通关指南
     * 
     * @param id 通关指南主键
     * @return 结果
     */
    public int deleteBWwwNewsRefById(Long id);

    /**
     * 批量删除通关指南
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBWwwNewsRefByIds(Long[] ids);
}
